/*
 * linux/arch/arm/mach-omap2/irq.h
 *
 * Interrupt handler for OMAP2 boards.
 *
 * Copyright (C) 2005-2007 Nokia Corporation
 * Contact: Igor Stoppa <igor.stoppa@nokia.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef __OMAP_IRQ_H
#define __OMAP_IRQ_H


/* List MPU irqs */
#define MPU_EMUINT		 0
#define MPU_COMMRX		 1
#define MPU_COMMTX		 2
#define MPU_BENCH		 3
#define MPU_XTI_IRQ		 4
#define MPU_XTI_WKUP_IRQ	 5
#define MPU_SSM_ABORT_IRQ	 6
#define MPU_SYS_nIRQ		 7
#define MPU_L3_IRQ		10
#define MPU_PRCM_MPU_IRQ	11
#define MPU_SDMA_IRQ0		12
#define MPU_SDMA_IRQ1		13
#define MPU_SDMA_IRQ2		14
#define MPU_SDMA_IRQ3		15
#define MPU_GPMC_IRQ		20
#define MPU_GFX_IRQ		21
#define MPU_IVA_IRQ		22
#define MPU_EAC_IRQ		23
#define MPU_CAM_IRQ0		24
#define MPU_DSS_IRQ		25
#define MPU_MAIL_MPU_IRQ	26
#define MPU_DSP_MMU_IRQ		28
#define MPU_GPIO1_MPU_IRQ	29
#define MPU_GPIO2_MPU_IRQ	30
#define MPU_GPIO3_MPU_IRQ	31
#define MPU_GPIO4_MPU_IRQ	32
#define MPU_MAIL_U3_MPU_IRQ	34
#define MPU_WDT3_IRQ		35
#define MPU_WDT4_IRQ		36
#define MPU_GPT1_IRQ		37
#define MPU_GPT2_IRQ		38
#define MPU_GPT3_IRQ		39
#define MPU_GPT4_IRQ		40
#define MPU_GPT5_IRQ		41
#define MPU_GPT6_IRQ		42
#define MPU_GPT7_IRQ		43
#define MPU_GPT8_IRQ		44
#define MPU_GPT9_IRQ		45
#define MPU_GPT10_IRQ		46
#define MPU_GPT11_IRQ		47
#define MPU_GPT12_IRQ		48
#define MPU_PKA_IRQ		50
#define MPU_SHA1MD5_IRQ		51
#define MPU_RNG_IRQ		52
#define MPU_MG_IRQ		53
#define MPU_I2C1_IRQ		56
#define MPU_I2C2_IRQ		57
#define MPU_HDQ_IRQ		58
#define MPU_McBSP1_IRQ_TX	59
#define MPU_McBSP1_IRQ_RX	60
#define MPU_McBSP2_IRQ_TX	62
#define MPU_McBSP2_IRQ_RX	63
#define MPU_SPI1_IRQ		65
#define MPU_SPI2_IRQ		66
#define MPU_SSI_P1_MPU_IRQ0	67
#define MPU_SSI_P1_MPU_IRQ1	68
#define MPU_SSI_P2_MPU_IRQ0	69
#define MPU_SSI_P2_MPU_IRQ1	70
#define MPU_SSI_GDD_MPU_IRQ	71
#define MPU_UART1_IRQ		72
#define MPU_UART2_IRQ		73
#define MPU_UART3_IRQ		74
#define MPU_USB_IRQ_GEN		75
#define MPU_USB_IRQ_NISO	76
#define MPU_USB_IRQ_ISO		77
#define MPU_USB_IRQ_HGEN	78
#define MPU_USB_IRQ_HSOF	79
#define MPU_USB_IRQ_OTG		80
#define MPU_VLYNQ_IRQ		81
#define MPU_MMC_IRQ		83
#define MPU_MS_IRQ		84
#define MPU_FAC_IRQ		85

enum intc_id{
	MPU_INTC = 0,
	DSP_INTC,
	IVA_INTC,
};

void omap_irq_fiq_enable(const int intc_id);
void omap_irq_fiq_disable(const int intc_id);
void omap_irq_fiq_save_flags(const int intc_id, u32 *flags);
void omap_irq_fiq_restore_flags(const int intc_id, const u32 flags);

static inline void omap_irqs_mask_set(unsigned int irq, u32 irqs_mask[])
{
	irqs_mask[irq / 32] |= 1 << (irq % 32);
}

static inline void omap_irqs_mask_clear(unsigned int irq, u32 irqs_mask[])
{
	irqs_mask[irq / 32] &= ~(1 << (irq % 32));
}

static inline void omap_irqs_mask_set_all(u32 irqs_mask[])
{
	irqs_mask[0] = irqs_mask[1] = irqs_mask[2] = ~0;
}

static inline void omap_irqs_mask_clear_all(u32 irqs_mask[])
{
	irqs_mask[0] = irqs_mask[1] = irqs_mask[2] = 0;
}

void omap_mask_irqs(const int intc_id, u32 irqs_mask[]);
void omap_unmask_irqs(const int intc_id, u32 irqs_mask[]);
void omap_save_irqs_mask(const int intc_id, u32 irqs_mask[]);
void omap_restore_irqs_mask(const int intc_id, u32 irqs_mask[]);

#endif
