/*
 * linux/include/asm-arm/arch-omap/pa.h
 *
 * Copyright (C) 2007 Nokia Corporation
 * Author: Sami Tolvanen
 * Maintainer: Timo O. Karjalainen <timo.o.karjalainen@nokia.com>
 *
 * OMAP HS protected applications (PA) format handling
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 */
#ifndef __ARCH_ARM_OMAP_PA_H
#define __ARCH_ARM_OMAP_PA_H

struct pa_format_command {
	u32 cmd;
	u8 filename[12];	/* TOC filename */
	u8 sa;			/* Sub-application */
	u8 index;		/* Function index */
	u8 npar;
	u8 nres;
};

struct pa_format_entry;

struct pa_command {
	struct pa_format_command *cmd;
	struct pa_format_entry *par;
	struct pa_format_entry *res;
};

struct pa_format {
	struct pa_command *cmd;	/* Commands */
	u32 ncmd;
};

typedef void *pa_ptr_conv(const void *);

struct pa_command_data {
	struct pa_command *c;
	struct pa_format *format;
	pa_ptr_conv *ptv;	/* Physical to virtual */
	pa_ptr_conv *vtp;	/* Virtual to physical */
	u32 cinp;
	u32 coup;
	u32 cpar;		/* PA parameter buffer size */
	u32 cres;		/* PA result buffer size */
	u8 *input;
	u8 *output;
	u8 *par;
	u8 *res;
	void *keys;		/* Public keys (KEYS) */
	void *papub;		/* PA public keys (PAPUBKEYS) */
};

extern void *pa_image_address(u8 *base, struct pa_format_command *cmd);

extern void pa_format_free(struct pa_format *p);

extern int pa_format_parse(u8 *base, u32 size, struct pa_format *p);

extern int pa_command_query(u32 cmd, u8 *input, u32 cinp, u32 *mininp,
			    u32 *maxout, struct pa_format *p);

extern int pa_command_prepare(u32 cmd, struct pa_command_data *p);

extern int pa_command_finish(struct pa_command_data *p);

#endif /* __ARCH_ARM_OMAP_PA_H */
