/*
 * linux/include/asm-arm/arch-omap/sec.h
 *
 * Copyright (C) 2007 Nokia Corporation
 * Author: Sami Tolvanen
 * Maintainer: Timo O. Karjalainen <timo.o.karjalainen@nokia.com>
 *
 * OMAP HS secure mode driver
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 */
#ifndef __ARCH_ARM_OMAP_SEC_H
#define __ARCH_ARM_OMAP_SEC_H

#define	SEC_CMD_NONE	 0
#define	SEC_CMD_INIT	 1
#define	SEC_CMD_SECS	 2
#define	SEC_CMD_RANDOM	 3
#define	SEC_CMD_PA_FIRST 0x100

/* Return codes */
#define SEC_NOTEXEC	0x00000000
#define SEC_OK		0x00000001
#define SEC_FAIL	0x00000002
#define SEC_ENOMEM	0x00000007
#define SEC_ENOPA	0xFFFFFFFF

#define SEC_STORAGE_SIZE	4096

struct sec_init {
	struct device *dev; /* sysfs device */
};

struct sec_result {
	u32 rv;		/* Secure ROM return value */
	u8  data[0];	/* Variable length */
};

struct sec_pa_result {
	u32 rom_rv;
	u32 pa_rv;
	u8  data[0];	/* Variable length */
};

/*
 * DEVICE I/O INTERFACE
 *
 * Begin all commands with a 32-bit command code (SEC_CMD_* or SEC_CMD_PA_*)
 * followed by 32-bit length of argument data. Structure of argument data is
 * documented in per-command structure definitions below.
 */
struct sec_cmd_header {
	u32 cmd;
	u32 length;
};

struct sec_cmd_init_args {
	u8 data[SEC_STORAGE_SIZE];	/* Secure storage contents */
};
/* Output of SEC_CMD_INIT is only return code. */

/* SEC_CMD_SECS does not take arguments */

struct sec_cmd_secs_output {
	u32 len;
	u8 data[SEC_STORAGE_SIZE];
};

struct sec_cmd_random_args {
	u32 len;	/* How many bytes of random data you want */
};
/* Output of SEC_CMD_RANDOM is the requested number of random bytes. */

struct sec_operations {
	int (*init)(struct sec_init *);
	void (*exit)(void);
	u32 (*secenv_init)(void *data, u32 len);
	u32 (*random_get)(void *buf, u32 len);
	u32 (*pa_query)(u32 cmd, u8 *input, u32 len, u32 *cpar, u32 *cres);
	void (*pa_service)(u32 cmd, u8 *input, u32 ilen,
			   struct sec_pa_result *out, u32 olen);
};

extern int sec_register(struct sec_operations *ops);
extern int sec_unregister(struct sec_operations *ops);
extern struct device *sec_get_device(void);
extern void sec_storage_write(void *storage, u32 size);

#endif /* __ARCH_ARM_OMAP_SEC_H */

